@@ -1,5 +1,5 @@
 from rest_framework.relations import PrimaryKeyRelatedField
-from djvue.fields import DEFAULT_DV_FORM_SIZE, DVField
+from djvue.fields import DVField
 
 
 # Attenzione: nel caso in cui si tratti di una relazione many to many, le informazioni non vengono prese dal get_dv_info
@@ -10,13 +10,12 @@ class DVAutocompletePrimaryKeyRelatedField(PrimaryKeyRelatedField, DVField):
     """
        Equivalent of DRF PrimaryKeyRelatedField
     """
-    allow_creation = False
-    placeholder = None
-    widget = None
+    allowCreation = False
+    # placeholder = None
+    # widget = None
     ac = True
 
-    def __init__(self, widget=None, placeholder=None, allow_creation=False, size=DEFAULT_DV_FORM_SIZE,
-                 *args, **kwargs):
+    def __init__(self, allowCreation=False, *args, **kwargs):
         """
 
         :param widget:
@@ -26,20 +25,17 @@ class DVAutocompletePrimaryKeyRelatedField(PrimaryKeyRelatedField, DVField):
         :param args:
         :param kwargs:
         """
-        self.placeholder = placeholder
-        self.allow_creation = allow_creation
-        self.widget = widget
-        self.size = size
+        # self.placeholder = placeholder
+        self.allowCreation = allowCreation
+        # self.widget = widget
+        # self.size = size
         PrimaryKeyRelatedField.__init__(self, **kwargs)
 
     class Meta(DVField.Meta):
-        dv_field = DVField.Meta.dv_field + ('ac', 'placeholder')
+        dv_field = DVField.Meta.dv_field + ('ac', 'allowCreation')
 
 
 class DVInlinePrimaryKeyRelatedField(PrimaryKeyRelatedField, DVField):
-    placeholder = None
 
-    def __init__(self, placeholder=None,
-                 *args, **kwargs):
-        self.placeholder = placeholder
-        PrimaryKeyRelatedField.__init__(self,many=True, **kwargs)
\ No newline at end of file
+    def __init__(self, *args, **kwargs):
+        PrimaryKeyRelatedField.__init__(self, many=True, **kwargs)
\ No newline at end of file
