@@ -15,7 +15,7 @@ class DjvueSimpleRouter(SimpleRouter):
                 name='{basename}-list_keys',
                 detail=False,
                 initkwargs={}
-            ), )
+            ))
 
         if hasattr(viewset, 'get_footer'):
             routes.append(Route(
@@ -26,29 +26,18 @@ class DjvueSimpleRouter(SimpleRouter):
                 name='{basename}-get_footer',
                 detail=False,
                 initkwargs={}
-            ), )
+            ))
 
         if hasattr(viewset, 'get_autocomplete'):
             routes.append(Route(
-                url=r'^{prefix}/autocomplete{trailing_slash}$',
+                url=r'^{prefix}/(\d+/)?autocomplete{trailing_slash}$',
                 mapping={
                     'get': 'get_autocomplete',
                 },
                 name='{basename}-autocomplete',
                 detail=False,
                 initkwargs={}
-            ), )
-
-        if hasattr(viewset, 'get_autocomplete'):
-            routes.append(Route(
-                url=r'^{prefix}/{lookup}{trailing_slash}autocomplete{trailing_slash}$',
-                mapping={
-                    'get': 'get_autocomplete',
-                },
-                name='{basename}-autocomplete',
-                detail=False,
-                initkwargs={}
-            ), )
+            ))
 
         routes += super().get_routes(viewset)
 
