@@ -1,5 +1,5 @@
 
-import {Component, Prop, Vue, Watch} from 'vue-property-decorator';
+import {Component} from 'vue-property-decorator';
 import BaseComponent from "@/components/BaseComponent";
 
 @Component({
@@ -7,7 +7,5 @@ import BaseComponent from "@/components/BaseComponent";
 })
 export default class FormComponent extends BaseComponent {
     private model: object = {};
-
-
 }
 
