@@ -112,30 +112,36 @@ class DjVueGenericViewSet(GenericViewSet, ListModelMixin):
 
         return Response({'error': _('Unknown field for autocomplete')}, status=500)
 
+    @property
     def allow_creation(self):
         return isinstance(self, CreateModelMixin)
 
+    @property
     def allow_retrieve(self):
         return isinstance(self, RetrieveModelMixin)
 
+    @property
     def allow_update(self):
         return isinstance(self, UpdateModelMixin)
 
+    @property
     def allow_delete(self):
         return isinstance(self, DestroyModelMixin)
 
+    @property
     def has_extra_buttons(self):
-        return self.action == 'list'
+        return self.allow_delete or self.allow_update or self.allow_creation or self.allow_retrieve
 
+    @property
     def has_footer(self):
         return hasattr(self, 'get_footer')
 
     def get_footer_config(self, view):
-        return Response({'footer': self.get_footer(view)})
+        return Response({'footer': self.get_footer()})
 
     def get_create_button(self):
         url_name = self.basename + '-list'
-        if self.allow_creation():
+        if self.allow_creation:
             return ModalButton(key='dv_create', props={
                 "baseUrl": reverse(url_name),
                 "operation": ModalFormOperation.CREATE,
@@ -154,7 +160,7 @@ class DjVueGenericViewSet(GenericViewSet, ListModelMixin):
         url_name = self.basename + '-detail'
         buttons = []
 
-        if self.allow_retrieve():
+        if self.allow_retrieve:
             buttons.append(ModalButton(key='dv_detail', props={
                 "baseUrl": reverse(url_name, kwargs={'pk': obj.id}),
                 "operation": ModalFormOperation.DETAIL,
@@ -165,7 +171,7 @@ class DjVueGenericViewSet(GenericViewSet, ListModelMixin):
                 }
             }).__dict__)
 
-        if self.allow_update():
+        if self.allow_update:
             buttons.append(ModalButton(key='dv_update', props={
                 "baseUrl": reverse(url_name, kwargs={'pk': obj.id}),
                 "operation": ModalFormOperation.UPDATE,
@@ -176,7 +182,7 @@ class DjVueGenericViewSet(GenericViewSet, ListModelMixin):
                 }
             }).__dict__)
 
-        if self.allow_delete():
+        if self.allow_delete:
             buttons.append(ModalButton(key='dv_delete', props={
                 "baseUrl": reverse(url_name, kwargs={'pk': obj.id}),
                 "operation": ModalFormOperation.DELETE,
@@ -194,7 +200,7 @@ class DjVueGenericViewSet(GenericViewSet, ListModelMixin):
         serializer_class = self.get_serializer_class()
         data = self.get_serializer_context()
 
-        if self.has_extra_buttons():
+        if self.has_extra_buttons:
             data["get_extra_buttons"] = self.get_extra_buttons
             serializer_class = type(serializer_class.__name__, (DjvueSerializerMixin, serializer_class), data)
 
